/*
****************************************************************************
****************************************************************************
**                                                                        **
**                XXXX     X    X         X XXXXXX X                      **
**               X    X   X X   X    X    X X      X   X                  **
**               X       X   X  X   X X   X X      X  X                   **
**               X   XX XXXXXXX X  X   X  X XXXX   X X                    **
**               X    X X     X X X     X X X      XX                     **
**               X    X X     X XX       XX X      X                      **
**                XXXX  X     X X         X XXXXXX XXXXXX                 **
**                                                                        **
**                           BIAYSTOK 2016                               **
**                                                                        **
**                         Home Control System                            **
**                                                                        **
**                              HC_PWC3                                   **
**                      Wersja z dnia : 2018.06.21                        **
**                     Napisal : Andrzej Pawluczuk                        **
**                                                                        **
****************************************************************************
****************************************************************************
*/
#include "pwc3eeprom.h"
#include <inttypes.h>
#include <avr/pgmspace.h>


#define null 0

uint8_t StandKey0CodeName [ ] PROGMEM         = "SK0" ;
uint8_t LongKey0CodeName [ ] PROGMEM          = "LK0" ;

EEPROMBlockDataRecT EEBlock ;

uint8_t ChOnCommand [ ] PROGMEM               = "CHON" ;
uint8_t ChOffCommand [ ] PROGMEM              = "CHOFF" ;
uint8_t ChInvCommand [ ] PROGMEM              = "CHINV" ;
uint8_t ChPulseOnCommand [ ] PROGMEM          = "CHPON" ;
uint8_t ChPulseOffCommand [ ] PROGMEM         = "CHPOFF" ;
uint8_t ChLongPulseOnCommand [ ] PROGMEM      = "CHLPON" ;
uint8_t ChLongPulseOffCommand [ ] PROGMEM     = "CHLPOFF" ;

static uint8_t MyDefaultID [ ] PROGMEM               = "PWC3" ;
static uint8_t SuperiorDeviceID [ ] PROGMEM          = "" ;
static uint8_t GlobalBaseDeviceID [ ] PROGMEM        = "" ;


static void EEPROMClearBlock ( void *   Destination ,
                               uint16_t Size )
{
  uint16_t Loop ;
  uint8_t * Dst ;
  /*----------------------------------------------------------------*/
  Dst = ( uint8_t * ) Destination ;
  for ( Loop = 0 ; Loop < Size ; Loop ++ )
    * Dst ++ = null ;
} /* EEPROMClearBlock */


static void SetIDFlash ( uint8_t * DeviceID , 
                         uint16_t  String )
{
  uint8_t Data ;
  uint8_t Loop ;
  uint8_t * DestCh ;
  /*----------------------------------------------------------------*/
  DestCh = DeviceID ;
  for ( Loop = 0 ; Loop <= DeviceIDSize ; Loop ++ )
    * DestCh ++ = null ;
  DestCh = DeviceID ;
  for ( Loop = 0 ; Loop < DeviceIDSize ; Loop ++ )
  {
    Data = pgm_read_byte_near ( String ++ ) ;
    if ( Data )
      * DestCh ++ = Data ;
    else
      break ;
  } /* for */ ;
} /* SetIDFlash */


void SetDefaultEEBlock ( void )
{
  /*----------------------------------------------------------------*/
  EEPROMClearBlock ( & EEBlock , sizeof ( EEPROMBlockDataRecT ) ) ;
  EEBlock . EEBlockMetric = StandardSygnature ;
  SetIDFlash ( EEBlock . MyDeviceID , ( uint16_t ) MyDefaultID ) ;
  EEBlock . Password [ 0 ] = 'M' ;
  EEBlock . Password [ 1 ] = 'A' ;
  EEBlock . Password [ 2 ] = 'G' ;
  EEBlock . Password [ 3 ] = 'I' ;
  EEBlock . Password [ 4 ] = 'C' ;
  EEBlock . Password [ 5 ] = null ;
  SetIDFlash ( EEBlock . StandardKeySerrvice . CommandText , ( uint16_t ) ChInvCommand ) ;
  EEBlock . StandardKeySerrvice . ParamValue = 0 ;
  SetIDFlash ( EEBlock . LongKeyService . CommandText , ( uint16_t ) ChOffCommand ) ;
  EEBlock . LongKeyService . ParamValue = 0 ;
  SetIDFlash ( EEBlock . EventDestinDeviceID [ 0 ] , ( uint16_t ) SuperiorDeviceID ) ;
  SetIDFlash ( EEBlock . EventDestinDeviceID [ 1 ] , ( uint16_t ) GlobalBaseDeviceID ) ;
  EEBlock . CRCValue = 0 ;
} /* SetDefaultEEBlock */


